@@ -1,10 +1,10 @@
-from .utils import Utils
+from .utils import SettingsReader
 import logging
 l = logging.getLogger(__name__)
 
 
 
-class AppSettings(Utils):
+class AppSettings(SettingsReader):
     myconf = ['adminname','adminpass','customtemplatesrc']
     customtemplatesrc = '/tmp'
 
@@ -12,5 +12,5 @@ class AppSettings(Utils):
 __allsettings={}
 
 def initAppSettings(prefix,classname):
-  newclass = type(classname  , (Utils,),{})
+  newclass = type(classname  , (SettingsReader,),{})
   __allsettings [classname  ] = newclass 
